summaryrefslogtreecommitdiff
path: root/sw
diff options
context:
space:
mode:
authorChris Sherlock <chris.sherlock79@gmail.com>2016-01-29 17:43:42 +1100
committerChris Sherlock <chris.sherlock79@gmail.com>2016-01-31 04:31:13 +0000
commit3187193a6142b4b1c974ae1e1de572fa74a3c8ee (patch)
tree6d9350492186d06a38703821336ba79cb72a8583 /sw
parent0bc3af3c1f719f9758ac01ff0b526abea7af0490 (diff)
tools: rename FontUnderline to FontLineStyle
Change-Id: I4750ad8569a1003b2f8c29052f3e25003ee433ca Reviewed-on: https://gerrit.libreoffice.org/21892 Tested-by: Jenkins <ci@libreoffice.org> Reviewed-by: Chris Sherlock <chris.sherlock79@gmail.com>
Diffstat (limited to 'sw')
-rw-r--r--sw/source/core/access/accpara.cxx2
-rw-r--r--sw/source/core/bastyp/init.cxx4
-rw-r--r--sw/source/core/doc/DocumentStylePoolManager.cxx8
-rw-r--r--sw/source/core/doc/notxtfrm.cxx2
-rw-r--r--sw/source/core/doc/tblafmt.cxx4
-rw-r--r--sw/source/core/inc/swfont.hxx20
-rw-r--r--sw/source/core/text/EnhancedPDFExportHelper.cxx8
-rw-r--r--sw/source/core/text/atrstck.cxx2
-rw-r--r--sw/source/core/text/itrform2.cxx6
-rw-r--r--sw/source/core/text/itrpaint.cxx6
-rw-r--r--sw/source/core/text/porfld.cxx8
-rw-r--r--sw/source/core/text/portxt.cxx8
-rw-r--r--sw/source/core/text/redlnitr.cxx8
-rw-r--r--sw/source/core/text/txtfld.cxx8
-rw-r--r--sw/source/core/text/txtftn.cxx4
-rw-r--r--sw/source/core/txtnode/fntcache.cxx14
-rw-r--r--sw/source/core/txtnode/fntcap.cxx16
-rw-r--r--sw/source/core/txtnode/swfont.cxx18
-rw-r--r--sw/source/filter/html/css1atr.cxx8
-rw-r--r--sw/source/filter/html/htmlatr.cxx8
-rw-r--r--sw/source/filter/html/htmlforw.cxx12
-rw-r--r--sw/source/filter/html/svxcss1.cxx14
-rw-r--r--sw/source/filter/html/swhtml.cxx2
-rw-r--r--sw/source/filter/ww8/docxattributeoutput.cxx36
-rw-r--r--sw/source/filter/ww8/rtfattributeoutput.cxx34
-rw-r--r--sw/source/filter/ww8/ww8atr.cxx36
-rw-r--r--sw/source/filter/ww8/ww8par6.cxx34
-rw-r--r--sw/source/ui/config/optpage.cxx12
-rw-r--r--sw/source/ui/table/tautofmt.cxx4
-rw-r--r--sw/source/uibase/app/swmodul1.cxx2
-rw-r--r--sw/source/uibase/config/modcfg.cxx8
-rw-r--r--sw/source/uibase/config/viewopt.cxx2
-rw-r--r--sw/source/uibase/shells/annotsh.cxx8
-rw-r--r--sw/source/uibase/shells/drwtxtex.cxx8
-rw-r--r--sw/source/uibase/shells/txtattr.cxx16
35 files changed, 195 insertions, 195 deletions
diff --git a/sw/source/core/access/accpara.cxx b/sw/source/core/access/accpara.cxx
index 7fdd058a9d63..0f71a4f861a1 100644
--- a/sw/source/core/access/accpara.cxx
+++ b/sw/source/core/access/accpara.cxx
@@ -2279,7 +2279,7 @@ void SwAccessibleParagraph::_correctValues( const sal_Int32 nIndex,
sal_Int32 nLen = 1;
if( pWrongList->InWrongWord(nBegin,nLen) && !pTextNode->IsSymbol(nBegin) )
{
- rValue.Value <<= (sal_uInt16)UNDERLINE_WAVE;
+ rValue.Value <<= (sal_uInt16)LINESTYLE_WAVE;
}
}
}
diff --git a/sw/source/core/bastyp/init.cxx b/sw/source/core/bastyp/init.cxx
index 274fd3a9d9a2..20c4f3bc81d3 100644
--- a/sw/source/core/bastyp/init.cxx
+++ b/sw/source/core/bastyp/init.cxx
@@ -479,7 +479,7 @@ void _InitCore()
aAttrTab[ RES_CHRATR_POSTURE- POOLATTR_BEGIN ] = new SvxPostureItem( ITALIC_NONE, RES_CHRATR_POSTURE );
aAttrTab[ RES_CHRATR_PROPORTIONALFONTSIZE- POOLATTR_BEGIN ] = new SvxPropSizeItem( 100, RES_CHRATR_PROPORTIONALFONTSIZE );
aAttrTab[ RES_CHRATR_SHADOWED- POOLATTR_BEGIN ] = new SvxShadowedItem( false, RES_CHRATR_SHADOWED );
- aAttrTab[ RES_CHRATR_UNDERLINE- POOLATTR_BEGIN ] = new SvxUnderlineItem( UNDERLINE_NONE, RES_CHRATR_UNDERLINE );
+ aAttrTab[ RES_CHRATR_UNDERLINE- POOLATTR_BEGIN ] = new SvxUnderlineItem( LINESTYLE_NONE, RES_CHRATR_UNDERLINE );
aAttrTab[ RES_CHRATR_WEIGHT- POOLATTR_BEGIN ] = new SvxWeightItem( WEIGHT_NORMAL, RES_CHRATR_WEIGHT );
aAttrTab[ RES_CHRATR_RSID - POOLATTR_BEGIN ] = new SvxRsidItem( 0, RES_CHRATR_RSID );
aAttrTab[ RES_CHRATR_WORDLINEMODE- POOLATTR_BEGIN ] = new SvxWordLineModeItem( false, RES_CHRATR_WORDLINEMODE );
@@ -509,7 +509,7 @@ void _InitCore()
aAttrTab[ RES_CHRATR_SCALEW - POOLATTR_BEGIN ] = new SvxCharScaleWidthItem( 100, RES_CHRATR_SCALEW );
aAttrTab[ RES_CHRATR_RELIEF - POOLATTR_BEGIN ] = new SvxCharReliefItem( RELIEF_NONE, RES_CHRATR_RELIEF );
aAttrTab[ RES_CHRATR_HIDDEN - POOLATTR_BEGIN ] = new SvxCharHiddenItem( false, RES_CHRATR_HIDDEN );
- aAttrTab[ RES_CHRATR_OVERLINE- POOLATTR_BEGIN ] = new SvxOverlineItem( UNDERLINE_NONE, RES_CHRATR_OVERLINE );
+ aAttrTab[ RES_CHRATR_OVERLINE- POOLATTR_BEGIN ] = new SvxOverlineItem( LINESTYLE_NONE, RES_CHRATR_OVERLINE );
aAttrTab[ RES_CHRATR_BOX - POOLATTR_BEGIN ] = new SvxBoxItem( RES_CHRATR_BOX );
aAttrTab[ RES_CHRATR_SHADOW - POOLATTR_BEGIN ] = new SvxShadowItem( RES_CHRATR_SHADOW );
aAttrTab[ RES_CHRATR_HIGHLIGHT - POOLATTR_BEGIN ] = new SvxBrushItem( RES_CHRATR_HIGHLIGHT );
diff --git a/sw/source/core/doc/DocumentStylePoolManager.cxx b/sw/source/core/doc/DocumentStylePoolManager.cxx
index 86a4cef87cc1..d52f9a680e33 100644
--- a/sw/source/core/doc/DocumentStylePoolManager.cxx
+++ b/sw/source/core/doc/DocumentStylePoolManager.cxx
@@ -1211,7 +1211,7 @@ SwFormat* DocumentStylePoolManager::GetFormatFromPool( sal_uInt16 nId )
{
Color aCol( COL_BLUE );
aSet.Put( SvxColorItem( aCol, RES_CHRATR_COLOR ) );
- aSet.Put( SvxUnderlineItem( UNDERLINE_SINGLE, RES_CHRATR_UNDERLINE ) );
+ aSet.Put( SvxUnderlineItem( LINESTYLE_SINGLE, RES_CHRATR_UNDERLINE ) );
// i40133: patch submitted by rail: set language to 'none' to prevent spell checking:
aSet.Put( SvxLanguageItem( LANGUAGE_NONE, RES_CHRATR_LANGUAGE ) );
aSet.Put( SvxLanguageItem( LANGUAGE_NONE, RES_CHRATR_CJK_LANGUAGE ) );
@@ -1222,7 +1222,7 @@ SwFormat* DocumentStylePoolManager::GetFormatFromPool( sal_uInt16 nId )
{
Color aCol( COL_RED );
aSet.Put( SvxColorItem( aCol, RES_CHRATR_COLOR ) );
- aSet.Put( SvxUnderlineItem( UNDERLINE_SINGLE, RES_CHRATR_UNDERLINE ) );
+ aSet.Put( SvxUnderlineItem( LINESTYLE_SINGLE, RES_CHRATR_UNDERLINE ) );
aSet.Put( SvxLanguageItem( LANGUAGE_NONE, RES_CHRATR_LANGUAGE ) );
aSet.Put( SvxLanguageItem( LANGUAGE_NONE, RES_CHRATR_CJK_LANGUAGE ) );
aSet.Put( SvxLanguageItem( LANGUAGE_NONE, RES_CHRATR_CTL_LANGUAGE ) );
@@ -1232,7 +1232,7 @@ SwFormat* DocumentStylePoolManager::GetFormatFromPool( sal_uInt16 nId )
{
Color aCol( COL_CYAN );
aSet.Put( SvxColorItem( aCol, RES_CHRATR_COLOR ) );
- aSet.Put( SvxUnderlineItem( UNDERLINE_DOTTED, RES_CHRATR_UNDERLINE ) );
+ aSet.Put( SvxUnderlineItem( LINESTYLE_DOTTED, RES_CHRATR_UNDERLINE ) );
aSet.Put( SvxCaseMapItem( SVX_CASEMAP_KAPITAELCHEN, RES_CHRATR_CASEMAP ) );
}
break;
@@ -1242,7 +1242,7 @@ SwFormat* DocumentStylePoolManager::GetFormatFromPool( sal_uInt16 nId )
long nH = static_cast<const SvxFontHeightItem*>(GetDfltAttr(
RES_CHRATR_CJK_FONTSIZE ))->GetHeight() / 2;
SetAllScriptItem( aSet, SvxFontHeightItem( nH, 100, RES_CHRATR_FONTSIZE));
- aSet.Put(SvxUnderlineItem( UNDERLINE_NONE, RES_CHRATR_UNDERLINE ));
+ aSet.Put(SvxUnderlineItem( LINESTYLE_NONE, RES_CHRATR_UNDERLINE ));
aSet.Put(SvxEmphasisMarkItem( EMPHASISMARK_NONE, RES_CHRATR_EMPHASIS_MARK) );
}
break;
diff --git a/sw/source/core/doc/notxtfrm.cxx b/sw/source/core/doc/notxtfrm.cxx
index e1e86963fd02..f5135921031d 100644
--- a/sw/source/core/doc/notxtfrm.cxx
+++ b/sw/source/core/doc/notxtfrm.cxx
@@ -109,7 +109,7 @@ static void lcl_PaintReplacement( const SwRect &rRect, const OUString &rText,
}
Color aCol( COL_RED );
- FontUnderline eUnderline = UNDERLINE_NONE;
+ FontLineStyle eUnderline = LINESTYLE_NONE;
const SwFormatURL &rURL = pFrame->FindFlyFrame()->GetFormat()->GetURL();
if( !rURL.GetURL().isEmpty() || rURL.GetMap() )
{
diff --git a/sw/source/core/doc/tblafmt.cxx b/sw/source/core/doc/tblafmt.cxx
index 59ee44244fc1..9edc798f7301 100644
--- a/sw/source/core/doc/tblafmt.cxx
+++ b/sw/source/core/doc/tblafmt.cxx
@@ -277,8 +277,8 @@ SwBoxAutoFormat::SwBoxAutoFormat()
m_aCTLWeight( WEIGHT_NORMAL, RES_CHRATR_CTL_WEIGHT ),
m_aCTLPosture( ITALIC_NONE, RES_CHRATR_CTL_POSTURE ),
- m_aUnderline( UNDERLINE_NONE, RES_CHRATR_UNDERLINE ),
- m_aOverline( UNDERLINE_NONE, RES_CHRATR_OVERLINE ),
+ m_aUnderline( LINESTYLE_NONE, RES_CHRATR_UNDERLINE ),
+ m_aOverline( LINESTYLE_NONE, RES_CHRATR_OVERLINE ),
m_aCrossedOut( STRIKEOUT_NONE, RES_CHRATR_CROSSEDOUT ),
m_aContour( false, RES_CHRATR_CONTOUR ),
m_aShadowed( false, RES_CHRATR_SHADOWED ),
diff --git a/sw/source/core/inc/swfont.hxx b/sw/source/core/inc/swfont.hxx
index 06f90312ee24..5df3acf3b48f 100644
--- a/sw/source/core/inc/swfont.hxx
+++ b/sw/source/core/inc/swfont.hxx
@@ -87,8 +87,8 @@ class SwSubFont : public SvxFont
inline void SetCharSet( const rtl_TextEncoding eCharSet );
inline void SetPitch( const FontPitch ePitch );
inline void SetAlign( const FontAlign eAlign );
- inline void SetUnderline( const FontUnderline eUnderline );
- inline void SetOverline( const FontUnderline eOverline );
+ inline void SetUnderline( const FontLineStyle eUnderline );
+ inline void SetOverline( const FontLineStyle eOverline );
inline void SetStrikeout( const FontStrikeout eStrikeout );
inline void SetItalic( const FontItalic eItalic );
inline void SetOutline( const bool bOutline );
@@ -209,9 +209,9 @@ public:
inline void SetColor( const Color& rColor );
inline void SetFillColor( const Color& rColor );
inline void SetAlign( const FontAlign eAlign );
- inline void SetUnderline( const FontUnderline eUnderline );
+ inline void SetUnderline( const FontLineStyle eUnderline );
inline void SetUnderColor( const Color &rColor ) { m_aUnderColor = rColor; }
- inline void SetOverline( const FontUnderline eOverline );
+ inline void SetOverline( const FontLineStyle eOverline );
inline void SetOverColor( const Color &rColor ) { m_aOverColor = rColor; }
inline void SetStrikeout( const FontStrikeout eStrikeout );
inline void SetOutline( const bool bOutline );
@@ -268,9 +268,9 @@ public:
bool IsSymbol( SwViewShell *pSh )
{ return m_aSub[m_nActual].IsSymbol( pSh ); }
- FontUnderline GetUnderline() const { return m_aSub[m_nActual].GetUnderline(); }
+ FontLineStyle GetUnderline() const { return m_aSub[m_nActual].GetUnderline(); }
const Color& GetUnderColor() const { return m_aUnderColor; }
- FontUnderline GetOverline() const { return m_aSub[m_nActual].GetOverline(); }
+ FontLineStyle GetOverline() const { return m_aSub[m_nActual].GetOverline(); }
const Color& GetOverColor() const { return m_aOverColor; }
FontStrikeout GetStrikeout() const { return m_aSub[m_nActual].GetStrikeout(); }
const Color& GetColor() const { return m_aSub[m_nActual].GetColor(); }
@@ -527,13 +527,13 @@ inline void SwFont::SetWeight( const FontWeight eWeight, const sal_uInt8 nWhich
}
// encapsulated SV-Font-method
-inline void SwSubFont::SetUnderline( const FontUnderline eUnderline )
+inline void SwSubFont::SetUnderline( const FontLineStyle eUnderline )
{
m_pMagic = nullptr;
Font::SetUnderline( eUnderline );
}
-inline void SwFont::SetUnderline( const FontUnderline eUnderline )
+inline void SwFont::SetUnderline( const FontLineStyle eUnderline )
{
m_bFontChg = true;
m_aSub[0].SetUnderline( eUnderline );
@@ -542,13 +542,13 @@ inline void SwFont::SetUnderline( const FontUnderline eUnderline )
}
// encapsulated SV-Font-method
-inline void SwSubFont::SetOverline( const FontUnderline eOverline )
+inline void SwSubFont::SetOverline( const FontLineStyle eOverline )
{
m_pMagic = nullptr;
Font::SetOverline( eOverline );
}
-inline void SwFont::SetOverline( const FontUnderline eOverline )
+inline void SwFont::SetOverline( const FontLineStyle eOverline )
{
m_bFontChg = true;
m_aSub[0].SetOverline( eOverline );
diff --git a/sw/source/core/text/EnhancedPDFExportHelper.cxx b/sw/source/core/text/EnhancedPDFExportHelper.cxx
index 5ae9240532ad..e6fc6c466f05 100644
--- a/sw/source/core/text/EnhancedPDFExportHelper.cxx
+++ b/sw/source/core/text/EnhancedPDFExportHelper.cxx
@@ -785,9 +785,9 @@ void SwTaggedPDFHelper::SetAttributes( vcl::PDFWriter::StructElement eType )
if ( bTextDecorationType )
{
- if ( UNDERLINE_NONE != rInf.GetFont()->GetUnderline() )
+ if ( LINESTYLE_NONE != rInf.GetFont()->GetUnderline() )
mpPDFExtOutDevData->SetStructureAttribute( vcl::PDFWriter::TextDecorationType, vcl::PDFWriter::Underline );
- if ( UNDERLINE_NONE != rInf.GetFont()->GetOverline() )
+ if ( LINESTYLE_NONE != rInf.GetFont()->GetOverline() )
mpPDFExtOutDevData->SetStructureAttribute( vcl::PDFWriter::TextDecorationType, vcl::PDFWriter::Overline );
if ( STRIKEOUT_NONE != rInf.GetFont()->GetStrikeout() )
mpPDFExtOutDevData->SetStructureAttribute( vcl::PDFWriter::TextDecorationType, vcl::PDFWriter::LineThrough );
@@ -1378,8 +1378,8 @@ void SwTaggedPDFHelper::BeginInlineStructureElements()
const sal_uInt8 nFont = rInf.GetFont()->GetActual();
const LanguageType nDefaultLang = SwEnhancedPDFExportHelper::GetDefaultLanguage();
- if ( UNDERLINE_NONE != rInf.GetFont()->GetUnderline() ||
- UNDERLINE_NONE != rInf.GetFont()->GetOverline() ||
+ if ( LINESTYLE_NONE != rInf.GetFont()->GetUnderline() ||
+ LINESTYLE_NONE != rInf.GetFont()->GetOverline() ||
STRIKEOUT_NONE != rInf.GetFont()->GetStrikeout() ||
EMPHASISMARK_NONE != rInf.GetFont()->GetEmphasisMark() ||
0 != rInf.GetFont()->GetEscapement() ||
diff --git a/sw/source/core/text/atrstck.cxx b/sw/source/core/text/atrstck.cxx
index c4933f0dd58a..103f32d6be62 100644
--- a/sw/source/core/text/atrstck.cxx
+++ b/sw/source/core/text/atrstck.cxx
@@ -795,7 +795,7 @@ void SwAttrHandler::FontChg(const SfxPoolItem& rItem, SwFont& rFnt, bool bPush )
if( mpShell && mpShell->GetWin())
{
if ( static_cast<const SvxCharHiddenItem&>(rItem).GetValue() )
- rFnt.SetUnderline( UNDERLINE_DOTTED );
+ rFnt.SetUnderline( LINESTYLE_DOTTED );
else
ActivateTop( rFnt, RES_CHRATR_UNDERLINE );
}
diff --git a/sw/source/core/text/itrform2.cxx b/sw/source/core/text/itrform2.cxx
index 9e6df3550d4d..2b1abbc13989 100644
--- a/sw/source/core/text/itrform2.cxx
+++ b/sw/source/core/text/itrform2.cxx
@@ -538,7 +538,7 @@ void SwTextFormatter::BuildPortions( SwTextFormatInfo &rInf )
// if we are underlined, we store the beginning of this underlined
// segment for repaint optimization
- if ( UNDERLINE_NONE != pFnt->GetUnderline() && ! nUnderLineStart )
+ if ( LINESTYLE_NONE != pFnt->GetUnderline() && ! nUnderLineStart )
nUnderLineStart = GetLeftMargin() + rInf.X();
if ( pPor->IsFlyPortion() )
@@ -557,12 +557,12 @@ void SwTextFormatter::BuildPortions( SwTextFormatInfo &rInf )
// reformat is at end of an underlined portion and next portion
// is not underlined
( ( rInf.GetReformatStart() == rInf.GetIdx() &&
- UNDERLINE_NONE == pFnt->GetUnderline()
+ LINESTYLE_NONE == pFnt->GetUnderline()
) ||
// reformat is inside portion and portion is underlined
( rInf.GetReformatStart() >= rInf.GetIdx() &&
rInf.GetReformatStart() <= rInf.GetIdx() + pPor->GetLen() &&
- UNDERLINE_NONE != pFnt->GetUnderline() ) ) )
+ LINESTYLE_NONE != pFnt->GetUnderline() ) ) )
rInf.SetPaintOfst( nUnderLineStart );
else if ( ! rInf.GetPaintOfst() &&
// 2. Right Tab
diff --git a/sw/source/core/text/itrpaint.cxx b/sw/source/core/text/itrpaint.cxx
index c5eba017cb04..91f9eea1b77f 100644
--- a/sw/source/core/text/itrpaint.cxx
+++ b/sw/source/core/text/itrpaint.cxx
@@ -61,7 +61,7 @@
// in SwTextPainter::CheckSpecialUnderline
bool IsUnderlineBreak( const SwLinePortion& rPor, const SwFont& rFnt )
{
- return UNDERLINE_NONE == rFnt.GetUnderline() ||
+ return LINESTYLE_NONE == rFnt.GetUnderline() ||
rPor.IsFlyPortion() || rPor.IsFlyCntPortion() ||
rPor.IsBreakPortion() || rPor.IsMarginPortion() ||
rPor.IsHolePortion() ||
@@ -502,7 +502,7 @@ void SwTextPainter::CheckSpecialUnderline( const SwLinePortion* pPor,
return;
//Bug 120769(End)
- OSL_ENSURE( GetFnt() && UNDERLINE_NONE != GetFnt()->GetUnderline(),
+ OSL_ENSURE( GetFnt() && LINESTYLE_NONE != GetFnt()->GetUnderline(),
"CheckSpecialUnderline without underlined font" );
MultiSelection aUnderMulti( Range( 0, GetInfo().GetText().getLength() ) );
const SwFont* pParaFnt = GetAttrHandler().GetFont();
@@ -652,7 +652,7 @@ void SwTextPainter::CheckSpecialUnderline( const SwLinePortion* pPor,
pUnderlineFnt->SetProportion( 100 );
pUnderlineFnt->SetEscapement( 0 );
pUnderlineFnt->SetStrikeout( STRIKEOUT_NONE );
- pUnderlineFnt->SetOverline( UNDERLINE_NONE );
+ pUnderlineFnt->SetOverline( LINESTYLE_NONE );
const Color aFillColor( COL_TRANSPARENT );
pUnderlineFnt->SetFillColor( aFillColor );
diff --git a/sw/source/core/text/porfld.cxx b/sw/source/core/text/porfld.cxx
index f72820b50544..792638dac411 100644
--- a/sw/source/core/text/porfld.cxx
+++ b/sw/source/core/text/porfld.cxx
@@ -665,13 +665,13 @@ void SwNumberPortion::Paint( const SwTextPaintInfo &rInf ) const
if( !aExpand.isEmpty() )
{
const SwFont *pTmpFnt = rInf.GetFont();
- bool bPaintSpace = ( UNDERLINE_NONE != pTmpFnt->GetUnderline() ||
- UNDERLINE_NONE != pTmpFnt->GetOverline() ||
+ bool bPaintSpace = ( LINESTYLE_NONE != pTmpFnt->GetUnderline() ||
+ LINESTYLE_NONE != pTmpFnt->GetOverline() ||
STRIKEOUT_NONE != pTmpFnt->GetStrikeout() ) &&
!pTmpFnt->IsWordLineMode();
if( bPaintSpace && pFnt )
- bPaintSpace = ( UNDERLINE_NONE != pFnt->GetUnderline() ||
- UNDERLINE_NONE != pFnt->GetOverline() ||
+ bPaintSpace = ( LINESTYLE_NONE != pFnt->GetUnderline() ||
+ LINESTYLE_NONE != pFnt->GetOverline() ||
STRIKEOUT_NONE != pFnt->GetStrikeout() ) &&
!pFnt->IsWordLineMode();
diff --git a/sw/source/core/text/portxt.cxx b/sw/source/core/text/portxt.cxx
index 5057cc88b609..bd6ee06067f1 100644
--- a/sw/source/core/text/portxt.cxx
+++ b/sw/source/core/text/portxt.cxx
@@ -745,13 +745,13 @@ void SwHolePortion::Paint( const SwTextPaintInfo &rInf ) const
const SwFont* pOrigFont = rInf.GetFont();
SwFont* pHoleFont = nullptr;
SwFontSave* pFontSave = nullptr;
- if( pOrigFont->GetUnderline() != UNDERLINE_NONE
- || pOrigFont->GetOverline() != UNDERLINE_NONE
+ if( pOrigFont->GetUnderline() != LINESTYLE_NONE
+ || pOrigFont->GetOverline() != LINESTYLE_NONE
|| pOrigFont->GetStrikeout() != STRIKEOUT_NONE )
{
pHoleFont = new SwFont( *pOrigFont );
- pHoleFont->SetUnderline( UNDERLINE_NONE );
- pHoleFont->SetOverline( UNDERLINE_NONE );
+ pHoleFont->SetUnderline( LINESTYLE_NONE );
+ pHoleFont->SetOverline( LINESTYLE_NONE );
pHoleFont->SetStrikeout( STRIKEOUT_NONE );
pFontSave = new SwFontSave( rInf, pHoleFont );
}
diff --git a/sw/source/core/text/redlnitr.cxx b/sw/source/core/text/redlnitr.cxx
index bc174dad6420..cc46a3e49851 100644
--- a/sw/source/core/text/redlnitr.cxx
+++ b/sw/source/core/text/redlnitr.cxx
@@ -405,13 +405,13 @@ bool SwRedlineItr::CheckLine( sal_Int32 nChkStart, sal_Int32 nChkEnd )
void SwExtend::ActualizeFont( SwFont &rFnt, sal_uInt16 nAttr )
{
if ( nAttr & EXTTEXTINPUT_ATTR_UNDERLINE )
- rFnt.SetUnderline( UNDERLINE_SINGLE );
+ rFnt.SetUnderline( LINESTYLE_SINGLE );
else if ( nAttr & EXTTEXTINPUT_ATTR_BOLDUNDERLINE )
- rFnt.SetUnderline( UNDERLINE_BOLD );
+ rFnt.SetUnderline( LINESTYLE_BOLD );
else if ( nAttr & EXTTEXTINPUT_ATTR_DOTTEDUNDERLINE )
- rFnt.SetUnderline( UNDERLINE_DOTTED );
+ rFnt.SetUnderline( LINESTYLE_DOTTED );
else if ( nAttr & EXTTEXTINPUT_ATTR_DASHDOTUNDERLINE )
- rFnt.SetUnderline( UNDERLINE_DOTTED );
+ rFnt.SetUnderline( LINESTYLE_DOTTED );
if ( nAttr & EXTTEXTINPUT_ATTR_REDTEXT )
rFnt.SetColor( Color( COL_RED ) );
diff --git a/sw/source/core/text/txtfld.cxx b/sw/source/core/text/txtfld.cxx
index ac97a06aed51..fdf673523538 100644
--- a/sw/source/core/text/txtfld.cxx
+++ b/sw/source/core/text/txtfld.cxx
@@ -516,8 +516,8 @@ SwNumberPortion *SwTextFormatter::NewNumberPortion( SwTextFormatInfo &rInf ) con
// Overline style of paragraph font should not be considered
// Weight style of paragraph font should not be considered
// Posture style of paragraph font should not be considered
- pNumFnt->SetUnderline( UNDERLINE_NONE );
- pNumFnt->SetOverline( UNDERLINE_NONE );
+ pNumFnt->SetUnderline( LINESTYLE_NONE );
+ pNumFnt->SetOverline( LINESTYLE_NONE );
pNumFnt->SetItalic( ITALIC_NONE, SW_LATIN );
pNumFnt->SetItalic( ITALIC_NONE, SW_CJK );
pNumFnt->SetItalic( ITALIC_NONE, SW_CTL );
@@ -577,9 +577,9 @@ SwNumberPortion *SwTextFormatter::NewNumberPortion( SwTextFormatInfo &rInf ) con
{
// i18463:
// Underline style of paragraph font should not be considered
- pNumFnt->SetUnderline( UNDERLINE_NONE );
+ pNumFnt->SetUnderline( LINESTYLE_NONE );
// Overline style of paragraph font should not be considered
- pNumFnt->SetOverline( UNDERLINE_NONE );
+ pNumFnt->SetOverline( LINESTYLE_NONE );
}
// Apply the explicit attributes from the character style
diff --git a/sw/source/core/text/txtftn.cxx b/sw/source/core/text/txtftn.cxx
index 8082dd29e45e..3ef8db04ef78 100644
--- a/sw/source/core/text/txtftn.cxx
+++ b/sw/source/core/text/txtftn.cxx
@@ -960,8 +960,8 @@ SwNumberPortion *SwTextFormatter::NewFootnoteNumPortion( SwTextFormatInfo &rInf
// Weight style of paragraph font should not be considered
// Posture style of paragraph font should not be considered
// See also #i18463# and SwTextFormatter::NewNumberPortion()
- pNumFnt->SetUnderline( UNDERLINE_NONE );
- pNumFnt->SetOverline( UNDERLINE_NONE );
+ pNumFnt->SetUnderline( LINESTYLE_NONE );
+ pNumFnt->SetOverline( LINESTYLE_NONE );
pNumFnt->SetItalic( ITALIC_NONE, SW_LATIN );
pNumFnt->SetItalic( ITALIC_NONE, SW_CJK );
pNumFnt->SetItalic( ITALIC_NONE, SW_CTL );
diff --git a/sw/source/core/txtnode/fntcap.cxx b/sw/source/core/txtnode/fntcap.cxx
index 55853b6bf5f3..ccd6936749b3 100644
--- a/sw/source/core/txtnode/fntcap.cxx
+++ b/sw/source/core/txtnode/fntcap.cxx
@@ -305,8 +305,8 @@ void SwSubFont::DrawCapital( SwDrawTextInfo &rInf )
{
// Es wird vorausgesetzt, dass rPos bereits kalkuliert ist!
// hochgezogen in SwFont: const Point aPos( CalcPos(rPos) );
- rInf.SetDrawSpace( GetUnderline() != UNDERLINE_NONE ||
- GetOverline() != UNDERLINE_NONE ||
+ rInf.SetDrawSpace( GetUnderline() != LINESTYLE_NONE ||
+ GetOverline() != LINESTYLE_NONE ||
GetStrikeout() != STRIKEOUT_NONE );
SwDoDrawCapital aDo( rInf );
DoOnCapitals( aDo );
@@ -457,8 +457,8 @@ void SwSubFont::DrawStretchCapital( SwDrawTextInfo &rInf )
const sal_uInt16 nCapWidth = (sal_uInt16)( GetCapitalSize( rInf ).Width() );
rInf.SetPos(aOldPos);
- rInf.SetDrawSpace( GetUnderline() != UNDERLINE_NONE ||
- GetOverline() != UNDERLINE_NONE ||
+ rInf.SetDrawSpace( GetUnderline() != LINESTYLE_NONE ||
+ GetOverline() != LINESTYLE_NONE ||
GetStrikeout() != STRIKEOUT_NONE );
SwDoDrawStretchCapital aDo( rInf, nCapWidth );
DoOnCapitals( aDo );
@@ -499,8 +499,8 @@ void SwSubFont::DoOnCapitals( SwDoCapitals &rDo )
SwSubFont aFont( *this );
Point aStartPos( rDo.GetInf().GetPos() );
- const bool bTextLines = aFont.GetUnderline() != UNDERLINE_NONE
- || aFont.GetOverline() != UNDERLINE_NONE
+ const bool bTextLines = aFont.GetUnderline() != LINESTYLE_NONE
+ || aFont.GetOverline() != LINESTYLE_NONE
|| aFont.GetStrikeout() != STRIKEOUT_NONE;
const bool bWordWise = bTextLines && aFont.IsWordLineMode() &&
rDo.GetInf().GetDrawSpace();
@@ -519,8 +519,8 @@ void SwSubFont::DoOnCapitals( SwDoCapitals &rDo )
pSpaceFont = pLastFont;
// Wir basteln uns einen Font fuer die Grossbuchstaben:
- aFont.SetUnderline( UNDERLINE_NONE );
- aFont.SetOverline( UNDERLINE_NONE );
+ aFont.SetUnderline( LINESTYLE_NONE );
+ aFont.SetOverline( LINESTYLE_NONE );
aFont.SetStrikeout( STRIKEOUT_NONE );
pMagic2 = nullptr;
nIndex2 = 0;
diff --git a/sw/source/core/txtnode/swfont.cxx b/sw/source/core/txtnode/swfont.cxx
index 5d47d9bc8064..012e913f1975 100644
--- a/sw/source/core/txtnode/swfont.cxx
+++ b/sw/source/core/txtnode/swfont.cxx
@@ -807,7 +807,7 @@ SwFont::SwFont( const SwAttrSet* pAttrSet,
m_aSub[SW_CTL].SetLanguage( pAttrSet->GetCTLLanguage().GetLanguage() );
}
if ( pAttrSet->GetCharHidden().GetValue() )
- SetUnderline( UNDERLINE_DOTTED );
+ SetUnderline( LINESTYLE_DOTTED );
else
SetUnderline( pAttrSet->GetUnderline().GetLineStyle() );
SetUnderColor( pAttrSet->GetUnderline().GetColor() );
@@ -982,8 +982,8 @@ bool SwSubFont::ChgFnt( SwViewShell const *pSh, OutputDevice& rOut )
pLastFont->SetDevFont( pSh, rOut );
pLastFont->Lock();
- return UNDERLINE_NONE != GetUnderline() ||
- UNDERLINE_NONE != GetOverline() ||
+ return LINESTYLE_NONE != GetUnderline() ||
+ LINESTYLE_NONE != GetOverline() ||
STRIKEOUT_NONE != GetStrikeout();
}
@@ -1169,13 +1169,13 @@ void SwSubFont::_DrawText( SwDrawTextInfo &rInf, const bool bGrey )
if( COMPLETE_STRING == rInf.GetLen() )
rInf.SetLen( nLn );
- FontUnderline nOldUnder = UNDERLINE_NONE;
+ FontLineStyle nOldUnder = LINESTYLE_NONE;
SwUnderlineFont* pUnderFnt = nullptr;
if( rInf.GetUnderFnt() )
{
nOldUnder = GetUnderline();
- SetUnderline( UNDERLINE_NONE );
+ SetUnderline( LINESTYLE_NONE );
pUnderFnt = rInf.GetUnderFnt();
}
@@ -1235,7 +1235,7 @@ void SwSubFont::_DrawText( SwDrawTextInfo &rInf, const bool bGrey )
}
}
- if( pUnderFnt && nOldUnder != UNDERLINE_NONE )
+ if( pUnderFnt && nOldUnder != LINESTYLE_NONE )
{
Size aFontSize = _GetTextSize( rInf );
const OUString oldStr = rInf.GetText();
@@ -1296,13 +1296,13 @@ void SwSubFont::_DrawStretchText( SwDrawTextInfo &rInf )
if( !rInf.GetLen() || !rInf.GetText().getLength() )
return;
- FontUnderline nOldUnder = UNDERLINE_NONE;
+ FontLineStyle nOldUnder = LINESTYLE_NONE;
SwUnderlineFont* pUnderFnt = nullptr;
if( rInf.GetUnderFnt() )
{
nOldUnder = GetUnderline();
- SetUnderline( UNDERLINE_NONE );
+ SetUnderline( LINESTYLE_NONE );
pUnderFnt = rInf.GetUnderFnt();
}
@@ -1347,7 +1347,7 @@ void SwSubFont::_DrawStretchText( SwDrawTextInfo &rInf )
rInf.GetText() ), rInf.GetIdx(), rInf.GetLen() );
}
- if( pUnderFnt && nOldUnder != UNDERLINE_NONE )
+ if( pUnderFnt && nOldUnder != LINESTYLE_NONE )
{
const OUString oldStr = rInf.GetText();
OUString aStr(" ");
diff --git a/sw/source/filter/html/css1atr.cxx b/sw/source/filter/html/css1atr.cxx
index e37125aa0ad3..518d2a9bc9e1 100644
--- a/sw/source/filter/html/css1atr.cxx
+++ b/sw/source/filter/html/css1atr.cxx
@@ -2324,10 +2324,10 @@ static Writer& OutCSS1_SvxTextLn_SvxCrOut_SvxBlink( Writer& rWrt,
{
switch( pUItem->GetLineStyle() )
{
- case UNDERLINE_NONE:
+ case LINESTYLE_NONE:
bNone = true;
break;
- case UNDERLINE_DONTKNOW:
+ case LINESTYLE_DONTKNOW:
break;
default:
if( !rHTMLWrt.IsCSS1Source( CSS1_OUTMODE_PARA ) )
@@ -2347,10 +2347,10 @@ static Writer& OutCSS1_SvxTextLn_SvxCrOut_SvxBlink( Writer& rWrt,
{
switch( pOItem->GetLineStyle() )
{
- case UNDERLINE_NONE:
+ case LINESTYLE_NONE:
bNone = true;
break;
- case UNDERLINE_DONTKNOW:
+ case LINESTYLE_DONTKNOW:
break;
default:
if( !rHTMLWrt.IsCSS1Source( CSS1_OUTMODE_PARA ) )
diff --git a/sw/source/filter/html/htmlatr.cxx b/sw/source/filter/html/htmlatr.cxx
index 476ce691058d..3e70ba9506d2 100644
--- a/sw/source/filter/html/htmlatr.cxx
+++ b/sw/source/filter/html/htmlatr.cxx
@@ -1271,10 +1271,10 @@ HTMLOnOffState HTMLEndPosLst::GetHTMLItemState( const SfxPoolItem& rItem )
case RES_CHRATR_UNDERLINE:
switch( static_cast<const SvxUnderlineItem&>(rItem).GetLineStyle() )
{
- case UNDERLINE_SINGLE:
+ case LINESTYLE_SINGLE:
eState = HTML_ON_VALUE;
break;
- case UNDERLINE_NONE:
+ case LINESTYLE_NONE:
eState = HTML_OFF_VALUE;
break;
default:
@@ -2878,8 +2878,8 @@ static Writer& OutHTML_SwUnderline( Writer& rWrt, const SfxPoolItem& rHt )
if( rHTMLWrt.m_bOutOpts )
return rWrt;
- const FontUnderline eUnder = static_cast<const SvxUnderlineItem&>(rHt).GetLineStyle();
- if( UNDERLINE_NONE != eUnder )
+ const FontLineStyle eUnder = static_cast<const SvxUnderlineItem&>(rHt).GetLineStyle();
+ if( LINESTYLE_NONE != eUnder )
{
HTMLOutFuncs::Out_AsciiTag( rWrt.Strm(), OOO_STRING_SVTOOLS_HTML_underline, rHTMLWrt.m_bTagOn );
}
diff --git a/sw/source/filter/html/htmlforw.cxx b/sw/source/filter/html/htmlforw.cxx
index 7b61ea1fd094..591a0cebecfc 100644
--- a/sw/source/filter/html/htmlforw.cxx
+++ b/sw/source/filter/html/htmlforw.cxx
@@ -1113,15 +1113,15 @@ Writer& OutHTML_DrawFrameFormatAsControl( Writer& rWrt,
aItemSet.Put( SvxPostureItem( eItalic, RES_CHRATR_POSTURE ) );
}
}
- if( xPropSetInfo->hasPropertyByName( "FontUnderline" ) )
+ if( xPropSetInfo->hasPropertyByName( "FontLineStyle" ) )
{
- aTmp = xPropSet->getPropertyValue( "FontUnderline" );
+ aTmp = xPropSet->getPropertyValue( "FontLineStyle" );
if( aTmp.getValueType() == ::cppu::UnoType<sal_Int16>::get() )
{
- FontUnderline eUnderline =
- (FontUnderline)*static_cast<sal_Int16 const *>(aTmp.getValue());
- if( eUnderline != UNDERLINE_DONTKNOW &&
- eUnderline != UNDERLINE_NONE )
+ FontLineStyle eUnderline =
+ (FontLineStyle)*static_cast<sal_Int16 const *>(aTmp.getValue());
+ if( eUnderline != LINESTYLE_DONTKNOW &&
+ eUnderline != LINESTYLE_NONE )
aItemSet.Put( SvxUnderlineItem( eUnderline, RES_CHRATR_UNDERLINE ) );
}
}
diff --git a/sw/source/filter/html/svxcss1.cxx b/sw/source/filter/html/svxcss1.cxx
index 641d75aa7cca..b8abbc05873c 100644
--- a/sw/source/filter/html/svxcss1.cxx
+++ b/sw/source/filter/html/svxcss1.cxx
@@ -1840,8 +1840,8 @@ static void ParseCSS1_text_decoration( const CSS1Expression *pExpr,
bool bCrossedOut = false;
bool bBlink = false;
bool bBlinkOn = false;
- FontUnderline eUnderline = UNDERLINE_NONE;
- FontUnderline eOverline = UNDERLINE_NONE;
+ FontLineStyle eUnderline = LINESTYLE_NONE;
+ FontLineStyle eOverline = LINESTYLE_NONE;
FontStrikeout eCrossedOut = STRIKEOUT_NONE;
// der Wert kann zwei Werte enthalten! Und MS-IE auch Strings
@@ -1857,10 +1857,10 @@ static void ParseCSS1_text_decoration( const CSS1Expression *pExpr,
if( aValue == "none" )
{
bUnderline = true;
- eUnderline = UNDERLINE_NONE;
+ eUnderline = LINESTYLE_NONE;
bOverline = true;
- eOverline = UNDERLINE_NONE;
+ eOverline = LINESTYLE_NONE;
bCrossedOut = true;
eCrossedOut = STRIKEOUT_NONE;
@@ -1876,7 +1876,7 @@ static void ParseCSS1_text_decoration( const CSS1Expression *pExpr,
if( aValue == "underline" )
{
bUnderline = true;
- eUnderline = UNDERLINE_SINGLE;
+ eUnderline = LINESTYLE_SINGLE;
bKnown = true;
}
@@ -1886,7 +1886,7 @@ static void ParseCSS1_text_decoration( const CSS1Expression *pExpr,
if( aValue == "overline" )
{
bOverline = true;
- eOverline = UNDERLINE_SINGLE;
+ eOverline = LINESTYLE_SINGLE;
bKnown = true;
}
@@ -1916,7 +1916,7 @@ static void ParseCSS1_text_decoration( const CSS1Expression *pExpr,
if( !bKnown )
{
bUnderline = true;
- eUnderline = UNDERLINE_SINGLE;
+ eUnderline = LINESTYLE_SINGLE;
}
pExpr = pExpr->GetNext();
diff --git a/sw/source/filter/html/swhtml.cxx b/sw/source/filter/html/swhtml.cxx
index e208f06daf6c..036992f41714 100644
--- a/sw/source/filter/html/swhtml.cxx
+++ b/sw/source/filter/html/swhtml.cxx
@@ -1771,7 +1771,7 @@ void SwHTMLParser::NextToken( int nToken )
case HTML_UNDERLINE_ON:
{
NewStdAttr( HTML_UNDERLINE_ON, &m_aAttrTab.pUnderline,
- SvxUnderlineItem(UNDERLINE_SINGLE, RES_CHRATR_UNDERLINE) );
+ SvxUnderlineItem(LINESTYLE_SINGLE, RES_CHRATR_UNDERLINE) );
}
break;
diff --git a/sw/source/filter/ww8/docxattributeoutput.cxx b/sw/source/filter/ww8/docxattributeoutput.cxx
index 1586054805f3..011e67952f3b 100644
--- a/sw/source/filter/ww8/docxattributeoutput.cxx
+++ b/sw/source/filter/ww8/docxattributeoutput.cxx
@@ -3926,7 +3926,7 @@ void DocxAttributeOutput::OutputDefaultItem(const SfxPoolItem& rHt)
bMustWrite = static_cast< const SvxShadowedItem& >(rHt).GetValue();
break;
case RES_CHRATR_UNDERLINE:
- bMustWrite = static_cast< const SvxUnderlineItem& >(rHt).GetLineStyle() != UNDERLINE_NONE;
+ bMustWrite = static_cast< const SvxUnderlineItem& >(rHt).GetLineStyle() != LINESTYLE_NONE;
break;
case RES_CHRATR_WEIGHT:
bMustWrite = static_cast< const SvxWeightItem& >(rHt).GetWeight() != WEIGHT_NORMAL;
@@ -6335,23 +6335,23 @@ void DocxAttributeOutput::CharUnderline( const SvxUnderlineItem& rUnderline )
switch ( rUnderline.GetLineStyle() )
{
- case UNDERLINE_SINGLE: pUnderlineValue = "single"; break;
- case UNDERLINE_BOLD: pUnderlineValue = "thick"; break;
- case UNDERLINE_DOUBLE: pUnderlineValue = "double"; break;
- case UNDERLINE_DOTTED: pUnderlineValue = "dotted"; break;
- case UNDERLINE_DASH: pUnderlineValue = "dash"; break;
- case UNDERLINE_DASHDOT: pUnderlineValue = "dotDash"; break;
- case UNDERLINE_DASHDOTDOT: pUnderlineValue = "dotDotDash"; break;
- case UNDERLINE_WAVE: pUnderlineValue = "wave"; break;
- case UNDERLINE_BOLDDOTTED: pUnderlineValue = "dottedHeavy"; break;
- case UNDERLINE_BOLDDASH: pUnderlineValue = "dashedHeavy"; break;
- case UNDERLINE_LONGDASH: pUnderlineValue = "dashLongHeavy"; break;
- case UNDERLINE_BOLDLONGDASH: pUnderlineValue = "dashLongHeavy"; break;
- case UNDERLINE_BOLDDASHDOT: pUnderlineValue = "dashDotHeavy"; break;
- case UNDERLINE_BOLDDASHDOTDOT: pUnderlineValue = "dashDotDotHeavy"; break;
- case UNDERLINE_BOLDWAVE: pUnderlineValue = "wavyHeavy"; break;
- case UNDERLINE_DOUBLEWAVE: pUnderlineValue = "wavyDouble"; break;
- case UNDERLINE_NONE: // fall through
+ case LINESTYLE_SINGLE: pUnderlineValue = "single"; break;
+ case LINESTYLE_BOLD: pUnderlineValue = "thick"; break;
+ case LINESTYLE_DOUBLE: pUnderlineValue = "double"; break;
+ case LINESTYLE_DOTTED: pUnderlineValue = "dotted"; break;
+ case LINESTYLE_DASH: pUnderlineValue = "dash"; break;
+ case LINESTYLE_DASHDOT: pUnderlineValue = "dotDash"; break;
+ case LINESTYLE_DASHDOTDOT: pUnderlineValue = "dotDotDash"; break;
+ case LINESTYLE_WAVE: pUnderlineValue = "wave"; break;
+ case LINESTYLE_BOLDDOTTED: pUnderlineValue = "dottedHeavy"; break;
+ case LINESTYLE_BOLDDASH: pUnderlineValue = "dashedHeavy"; break;
+ case LINESTYLE_LONGDASH: pUnderlineValue = "dashLongHeavy"; break;
+ case LINESTYLE_BOLDLONGDASH: pUnderlineValue = "dashLongHeavy"; break;
+ case LINESTYLE_BOLDDASHDOT: pUnderlineValue = "dashDotHeavy"; break;
+ case LINESTYLE_BOLDDASHDOTDOT: pUnderlineValue = "dashDotDotHeavy"; break;
+ case LINESTYLE_BOLDWAVE: pUnderlineValue = "wavyHeavy"; break;
+ case LINESTYLE_DOUBLEWAVE: pUnderlineValue = "wavyDouble"; break;
+ case LINESTYLE_NONE: // fall through
default: pUnderlineValue = "none"; break;
}
diff --git a/sw/source/filter/ww8/rtfattributeoutput.cxx b/sw/source/filter/ww8/rtfattributeoutput.cxx
index 46d9ed9f377f..34a171a0bfbf 100644
--- a/sw/source/filter/ww8/rtfattributeoutput.cxx
+++ b/sw/source/filter/ww8/rtfattributeoutput.cxx
@@ -2364,55 +2364,55 @@ void RtfAttributeOutput::CharUnderline(const SvxUnderlineItem& rUnderline)
bWord = static_cast<const SvxWordLineModeItem*>(pItem)->GetValue();
switch (rUnderline.GetLineStyle())
{
- case UNDERLINE_SINGLE:
+ case LINESTYLE_SINGLE:
pStr = bWord ? OOO_STRING_SVTOOLS_RTF_ULW : OOO_STRING_SVTOOLS_RTF_UL;
break;
- case UNDERLINE_DOUBLE:
+ case LINESTYLE_DOUBLE:
pStr = OOO_STRING_SVTOOLS_RTF_ULDB;
break;
- case UNDERLINE_NONE:
+ case LINESTYLE_NONE:
pStr = OOO_STRING_SVTOOLS_RTF_ULNONE;
break;
- case UNDERLINE_DOTTED:
+ case LINESTYLE_DOTTED:
pStr = OOO_STRING_SVTOOLS_RTF_ULD;
break;
- case UNDERLINE_DASH:
+ case LINESTYLE_DASH:
pStr = OOO_STRING_SVTOOLS_RTF_ULDASH;
break;
- case UNDERLINE_DASHDOT:
+ case LINESTYLE_DASHDOT:
pStr = OOO_STRING_SVTOOLS_RTF_ULDASHD;
break;
- case UNDERLINE_DASHDOTDOT:
+ case LINESTYLE_DASHDOTDOT:
pStr = OOO_STRING_SVTOOLS_RTF_ULDASHDD;
break;
- case UNDERLINE_BOLD:
+ case LINESTYLE_BOLD:
pStr = OOO_STRING_SVTOOLS_RTF_ULTH;
break;
- case UNDERLINE_WAVE:
+ case LINESTYLE_WAVE:
pStr = OOO_STRING_SVTOOLS_RTF_ULWAVE;
break;
- case UNDERLINE_BOLDDOTTED:
+ case LINESTYLE_BOLDDOTTED:
pStr = OOO_STRING_SVTOOLS_RTF_ULTHD;
break;
- case UNDERLINE_BOLDDASH:
+ case LINESTYLE_BOLDDASH:
pStr = OOO_STRING_SVTOOLS_RTF_ULTHDASH;
break;
- case UNDERLINE_LONGDASH:
+ case LINESTYLE_LONGDASH:
pStr = OOO_STRING_SVTOOLS_RTF_ULLDASH;
break;
- case UNDERLINE_BOLDLONGDASH:
+ case LINESTYLE_BOLDLONGDASH:
pStr = OOO_STRING_SVTOOLS_RTF_ULTHLDASH;
break;
- case UNDERLINE_BOLDDASHDOT:
+ case LINESTYLE_BOLDDASHDOT:
pStr = OOO_STRING_SVTOOLS_RTF_ULTHDASHD;
break;
- case UNDERLINE_BOLDDASHDOTDOT:
+ case LINESTYLE_BOLDDASHDOTDOT:
pStr = OOO_STRING_SVTOOLS_RTF_ULTHDASHDD;
break;
- case UNDERLINE_BOLDWAVE:
+ case LINESTYLE_BOLDWAVE:
pStr = OOO_STRING_SVTOOLS_RTF_ULHWAVE;
break;
- case UNDERLINE_DOUBLEWAVE:
+ case LINESTYLE_DOUBLEWAVE:
pStr = OOO_STRING_SVTOOLS_RTF_ULULDBWAVE;
break;
default:
diff --git a/sw/source/filter/ww8/ww8atr.cxx b/sw/source/filter/ww8/ww8atr.cxx
index a1f9d83e5dde..eb30f1d81bda 100644
--- a/sw/source/filter/ww8/ww8atr.cxx
+++ b/sw/source/filter/ww8/ww8atr.cxx
@@ -1208,60 +1208,60 @@ void WW8AttributeOutput::CharUnderline( const SvxUnderlineItem& rUnderline )
sal_uInt8 b = 0;
switch ( rUnderline.GetLineStyle() )
{
- case UNDERLINE_SINGLE:
+ case LINESTYLE_SINGLE:
b = ( bWord ) ? 2 : 1;
break;
- case UNDERLINE_BOLD:
+ case LINESTYLE_BOLD:
b = 6;
break;
- case UNDERLINE_DOUBLE:
+ case LINESTYLE_DOUBLE:
b = 3;
break;
- case UNDERLINE_DOTTED:
+ case LINESTYLE_DOTTED:
b = 4;
break;
- case UNDERLINE_DASH:
+ case LINESTYLE_DASH:
b = 7;
break;
- case UNDERLINE_DASHDOT:
+ case LINESTYLE_DASHDOT:
b = 9;
break;
- case UNDERLINE_DASHDOTDOT:
+ case LINESTYLE_DASHDOTDOT:
b = 10;
break;
- case UNDERLINE_WAVE:
+ case LINESTYLE_WAVE:
b = 11;
break;
// new in WW2000
- case UNDERLINE_BOLDDOTTED:
+ case LINESTYLE_BOLDDOTTED:
b = 20;
break;
- case UNDERLINE_BOLDDASH:
+ case LINESTYLE_BOLDDASH:
b = 23;
break;
- case UNDERLINE_LONGDASH:
+ case LINESTYLE_LONGDASH:
b = 39;
break;
- case UNDERLINE_BOLDLONGDASH:
+ case LINESTYLE_BOLDLONGDASH:
b = 55;
break;
- case UNDERLINE_BOLDDASHDOT:
+ case LINESTYLE_BOLDDASHDOT:
b = 25;
break;
- case UNDERLINE_BOLDDASHDOTDOT:
+ case LINESTYLE_BOLDDASHDOTDOT:
b = 26;
break;
- case UNDERLINE_BOLDWAVE:
+ case LINESTYLE_BOLDWAVE:
b = 27;
break;
- case UNDERLINE_DOUBLEWAVE:
+ case LINESTYLE_DOUBLEWAVE:
b = 43;
break;
- case UNDERLINE_NONE:
+ case LINESTYLE_NONE:
b = 0;
break;
default:
- OSL_ENSURE( rUnderline.GetLineStyle() == UNDERLINE_NONE, "Unhandled underline type" );
+ OSL_ENSURE( rUnderline.GetLineStyle() == LINESTYLE_NONE, "Unhandled underline type" );
break;
}
diff --git a/sw/source/filter/ww8/ww8par6.cxx b/sw/source/filter/ww8/ww8par6.cxx
index 092f5650f3eb..a4eb8755478d 100644
--- a/sw/source/filter/ww8/ww8par6.cxx
+++ b/sw/source/filter/ww8/ww8par6.cxx
@@ -3260,7 +3260,7 @@ void SwWW8ImplReader::Read_SubSuperProp( sal_uInt16, const sal_uInt8* pData, sho
void SwWW8ImplReader::Read_Underline( sal_uInt16, const sal_uInt8* pData, short nLen )
{
- FontUnderline eUnderline = UNDERLINE_NONE;
+ FontLineStyle eUnderline = LINESTYLE_NONE;
bool bWordLine = false;
if( pData )
{
@@ -3271,22 +3271,22 @@ void SwWW8ImplReader::Read_Underline( sal_uInt16, const sal_uInt8* pData, short
switch( *pData )
{
case 2: bWordLine = true; // no break;
- case 1: eUnderline = (FontUnderline)UNDERLINE_SINGLE; break;
- case 3: eUnderline = (FontUnderline)UNDERLINE_DOUBLE; break;
- case 4: eUnderline = (FontUnderline)UNDERLINE_DOTTED; break;
- case 7: eUnderline = (FontUnderline)UNDERLINE_DASH; break;
- case 9: eUnderline = (FontUnderline)UNDERLINE_DASHDOT; break;
- case 10:eUnderline = (FontUnderline)UNDERLINE_DASHDOTDOT; break;
- case 6: eUnderline = (FontUnderline)UNDERLINE_BOLD; break;
- case 11:eUnderline = (FontUnderline)UNDERLINE_WAVE; break;
- case 20:eUnderline = (FontUnderline)UNDERLINE_BOLDDOTTED; break;
- case 23:eUnderline = (FontUnderline)UNDERLINE_BOLDDASH; break;
- case 39:eUnderline = (FontUnderline)UNDERLINE_LONGDASH; break;
- case 55:eUnderline = (FontUnderline)UNDERLINE_BOLDLONGDASH; break;
- case 25:eUnderline = (FontUnderline)UNDERLINE_BOLDDASHDOT; break;
- case 26:eUnderline = (FontUnderline)UNDERLINE_BOLDDASHDOTDOT;break;
- case 27:eUnderline = (FontUnderline)UNDERLINE_BOLDWAVE; break;
- case 43:eUnderline = (FontUnderline)UNDERLINE_DOUBLEWAVE; break;
+ case 1: eUnderline = (FontLineStyle)LINESTYLE_SINGLE; break;
+ case 3: eUnderline = (FontLineStyle)LINESTYLE_DOUBLE; break;
+ case 4: eUnderline = (FontLineStyle)LINESTYLE_DOTTED; break;
+ case 7: eUnderline = (FontLineStyle)LINESTYLE_DASH; break;
+ case 9: eUnderline = (FontLineStyle)LINESTYLE_DASHDOT; break;
+ case 10:eUnderline = (FontLineStyle)LINESTYLE_DASHDOTDOT; break;
+ case 6: eUnderline = (FontLineStyle)LINESTYLE_BOLD; break;
+ case 11:eUnderline = (FontLineStyle)LINESTYLE_WAVE; break;
+ case 20:eUnderline = (FontLineStyle)LINESTYLE_BOLDDOTTED; break;
+ case 23:eUnderline = (FontLineStyle)LINESTYLE_BOLDDASH; break;
+ case 39:eUnderline = (FontLineStyle)LINESTYLE_LONGDASH; break;
+ case 55:eUnderline = (FontLineStyle)LINESTYLE_BOLDLONGDASH; break;
+ case 25:eUnderline = (FontLineStyle)LINESTYLE_BOLDDASHDOT; break;
+ case 26:eUnderline = (FontLineStyle)LINESTYLE_BOLDDASHDOTDOT;break;
+ case 27:eUnderline = (FontLineStyle)LINESTYLE_BOLDWAVE; break;
+ case 43:eUnderline = (FontLineStyle)LINESTYLE_DOUBLEWAVE; break;
}
}
diff --git a/sw/source/ui/config/optpage.cxx b/sw/source/ui/config/optpage.cxx
index d12d037c5dc6..2c0c8d13938e 100644
--- a/sw/source/ui/config/optpage.cxx
+++ b/sw/source/ui/config/optpage.cxx
@@ -1544,8 +1544,8 @@ static CharAttr aRedlineAttr[] =
{ SID_ATTR_CHAR_CASEMAP, SVX_CASEMAP_NOT_MAPPED },
{ SID_ATTR_CHAR_WEIGHT, WEIGHT_BOLD },
{ SID_ATTR_CHAR_POSTURE, ITALIC_NORMAL },
- { SID_ATTR_CHAR_UNDERLINE, UNDERLINE_SINGLE },
- { SID_ATTR_CHAR_UNDERLINE, UNDERLINE_DOUBLE },
+ { SID_ATTR_CHAR_UNDERLINE, LINESTYLE_SINGLE },
+ { SID_ATTR_CHAR_UNDERLINE, LINESTYLE_DOUBLE },
{ SID_ATTR_CHAR_STRIKEOUT, STRIKEOUT_SINGLE },
{ SID_ATTR_CHAR_CASEMAP, SVX_CASEMAP_VERSALIEN },
{ SID_ATTR_CHAR_CASEMAP, SVX_CASEMAP_GEMEINE },
@@ -2101,8 +2101,8 @@ IMPL_LINK_TYPED( SwRedlineOptionsTabPage, AttribHdl, ListBox&, rLB, void )
rCJKFont.SetWeight(WEIGHT_NORMAL);
rFont.SetItalic(ITALIC_NONE);
rCJKFont.SetItalic(ITALIC_NONE);
- rFont.SetUnderline(UNDERLINE_NONE);
- rCJKFont.SetUnderline(UNDERLINE_NONE);
+ rFont.SetUnderline(LINESTYLE_NONE);
+ rCJKFont.SetUnderline(LINESTYLE_NONE);
rFont.SetStrikeout(STRIKEOUT_NONE);
rCJKFont.SetStrikeout(STRIKEOUT_NONE);
rFont.SetCaseMap(SVX_CASEMAP_NOT_MAPPED);
@@ -2147,8 +2147,8 @@ IMPL_LINK_TYPED( SwRedlineOptionsTabPage, AttribHdl, ListBox&, rLB, void )
break;
case SID_ATTR_CHAR_UNDERLINE:
- rFont.SetUnderline( ( FontUnderline ) pAttr->nAttr );
- rCJKFont.SetUnderline( ( FontUnderline ) pAttr->nAttr );
+ rFont.SetUnderline( ( FontLineStyle ) pAttr->nAttr );
+ rCJKFont.SetUnderline( ( FontLineStyle ) pAttr->nAttr );
break;
case SID_ATTR_CHAR_STRIKEOUT:
diff --git a/sw/source/ui/table/tautofmt.cxx b/sw/source/ui/table/tautofmt.cxx
index 6eae65389b70..3ecbd16825ce 100644
--- a/sw/source/ui/table/tautofmt.cxx
+++ b/sw/source/ui/table/tautofmt.cxx
@@ -590,8 +590,8 @@ void AutoFormatPreview::MakeFonts( sal_uInt8 nIndex, vcl::Font& rFont, vcl::Font
lcl_SetFontProperties( rCJKFont, rBoxFormat.GetCJKFont(), rBoxFormat.GetCJKWeight(), rBoxFormat.GetCJKPosture() );
lcl_SetFontProperties( rCTLFont, rBoxFormat.GetCTLFont(), rBoxFormat.GetCTLWeight(), rBoxFormat.GetCTLPosture() );
- SETONALLFONTS( SetUnderline, (FontUnderline)rBoxFormat.GetUnderline().GetValue() );
- SETONALLFONTS( SetOverline, (FontUnderline)rBoxFormat.GetOverline().GetValue() );
+ SETONALLFONTS( SetUnderline, (FontLineStyle)rBoxFormat.GetUnderline().GetValue() );
+ SETONALLFONTS( SetOverline, (FontLineStyle)rBoxFormat.GetOverline().GetValue() );
SETONALLFONTS( SetStrikeout, (FontStrikeout)rBoxFormat.GetCrossedOut().GetValue() );
SETONALLFONTS( SetOutline, rBoxFormat.GetContour().GetValue() );
SETONALLFONTS( SetShadow, rBoxFormat.GetShadowed().GetValue() );
diff --git a/sw/source/uibase/app/swmodul1.cxx b/sw/source/uibase/app/swmodul1.cxx
index 649937193ea2..d9d52fbd8a1b 100644
--- a/sw/source/uibase/app/swmodul1.cxx
+++ b/sw/source/uibase/app/swmodul1.cxx
@@ -479,7 +479,7 @@ static void lcl_FillAuthorAttr( sal_uInt16 nAuthor, SfxItemSet &rSet,
break;
case SID_ATTR_CHAR_UNDERLINE:
- rSet.Put( SvxUnderlineItem( (FontUnderline)rAttr.nAttr,
+ rSet.Put( SvxUnderlineItem( (FontLineStyle)rAttr.nAttr,
RES_CHRATR_UNDERLINE));
break;
diff --git a/sw/source/uibase/config/modcfg.cxx b/sw/source/uibase/config/modcfg.cxx
index 956b074517ca..92c331d9b54a 100644
--- a/sw/source/uibase/config/modcfg.cxx
+++ b/sw/source/uibase/config/modcfg.cxx
@@ -249,7 +249,7 @@ SwRevisionConfig::SwRevisionConfig() :
ConfigItemMode::DelayedUpdate|ConfigItemMode::ReleaseTree)
{
aInsertAttr.nItemId = SID_ATTR_CHAR_UNDERLINE;
- aInsertAttr.nAttr = UNDERLINE_SINGLE;
+ aInsertAttr.nAttr = LINESTYLE_SINGLE;
aInsertAttr.nColor = COL_TRANSPARENT;
aDeletedAttr.nItemId = SID_ATTR_CHAR_STRIKEOUT;
aDeletedAttr.nAttr = STRIKEOUT_SINGLE;
@@ -272,7 +272,7 @@ static sal_Int32 lcl_ConvertAttrToCfg(const AuthorCharAttr& rAttr)
{
case SID_ATTR_CHAR_WEIGHT: nRet = 1; break;
case SID_ATTR_CHAR_POSTURE: nRet = 2; break;
- case SID_ATTR_CHAR_UNDERLINE: nRet = UNDERLINE_SINGLE == rAttr.nAttr ? 3 : 4; break;
+ case SID_ATTR_CHAR_UNDERLINE: nRet = LINESTYLE_SINGLE == rAttr.nAttr ? 3 : 4; break;
case SID_ATTR_CHAR_STRIKEOUT: nRet = 3; break;
case SID_ATTR_CHAR_CASEMAP:
{
@@ -332,10 +332,10 @@ static void lcl_ConvertCfgToAttr(sal_Int32 nVal, AuthorCharAttr& rAttr, bool bDe
else
{
rAttr.nItemId = SID_ATTR_CHAR_UNDERLINE;
- rAttr.nAttr = UNDERLINE_SINGLE;
+ rAttr.nAttr = LINESTYLE_SINGLE;
}
break;
- case 4: rAttr.nItemId = SID_ATTR_CHAR_UNDERLINE;rAttr.nAttr = UNDERLINE_DOUBLE ; break;
+ case 4: rAttr.nItemId = SID_ATTR_CHAR_UNDERLINE;rAttr.nAttr = LINESTYLE_DOUBLE ; break;
case 5: rAttr.nItemId = SID_ATTR_CHAR_CASEMAP; rAttr.nAttr = SVX_CASEMAP_VERSALIEN ; break;
case 6: rAttr.nItemId = SID_ATTR_CHAR_CASEMAP; rAttr.nAttr = SVX_CASEMAP_GEMEINE ; break;
case 7: rAttr.nItemId = SID_ATTR_CHAR_CASEMAP; rAttr.nAttr = SVX_CASEMAP_KAPITAELCHEN ; break;
diff --git a/sw/source/uibase/config/viewopt.cxx b/sw/source/uibase/config/viewopt.cxx
index b40e0fc17c0b..09be8c4cacf1 100644
--- a/sw/source/uibase/config/viewopt.cxx
+++ b/sw/source/uibase/config/viewopt.cxx
@@ -327,7 +327,7 @@ void SwViewOption::SetOnlineSpell(bool b)
AuthorCharAttr::AuthorCharAttr() :
nItemId (SID_ATTR_CHAR_UNDERLINE),
- nAttr (UNDERLINE_SINGLE),
+ nAttr (LINESTYLE_SINGLE),
nColor (COL_TRANSPARENT)
{
}
diff --git a/sw/source/uibase/shells/annotsh.cxx b/sw/source/uibase/shells/annotsh.cxx
index f19da7ecab9a..6cd4b83e0ba8 100644
--- a/sw/source/uibase/shells/annotsh.cxx
+++ b/sw/source/uibase/shells/annotsh.cxx
@@ -283,16 +283,16 @@ void SwAnnotationShell::Exec( SfxRequest &rReq )
}
else
{
- FontUnderline eFU = static_cast<const SvxUnderlineItem&>( aEditAttr.Get( EE_CHAR_UNDERLINE ) ).GetLineStyle();
- aNewAttr.Put( SvxUnderlineItem( eFU != UNDERLINE_NONE ?UNDERLINE_NONE : UNDERLINE_SINGLE, EE_CHAR_UNDERLINE ) );
+ FontLineStyle eFU = static_cast<const SvxUnderlineItem&>( aEditAttr.Get( EE_CHAR_UNDERLINE ) ).GetLineStyle();
+ aNewAttr.Put( SvxUnderlineItem( eFU != LINESTYLE_NONE ?LINESTYLE_NONE : LINESTYLE_SINGLE, EE_CHAR_UNDERLINE ) );
}
}
break;
}
case SID_ATTR_CHAR_OVERLINE:
{
- FontUnderline eFO = static_cast<const SvxOverlineItem&>(aEditAttr.Get(EE_CHAR_OVERLINE)).GetLineStyle();
- aNewAttr.Put(SvxOverlineItem(eFO == UNDERLINE_SINGLE ? UNDERLINE_NONE : UNDERLINE_SINGLE, EE_CHAR_OVERLINE));
+ FontLineStyle eFO = static_cast<const SvxOverlineItem&>(aEditAttr.Get(EE_CHAR_OVERLINE)).GetLineStyle();
+ aNewAttr.Put(SvxOverlineItem(eFO == LINESTYLE_SINGLE ? LINESTYLE_NONE : LINESTYLE_SINGLE, EE_CHAR_OVERLINE));
break;
}
case SID_ATTR_CHAR_CONTOUR: nEEWhich = EE_CHAR_OUTLINE; break;
diff --git a/sw/source/uibase/shells/drwtxtex.cxx b/sw/source/uibase/shells/drwtxtex.cxx
index 377753d781fb..e90bc5a2d797 100644
--- a/sw/source/uibase/shells/drwtxtex.cxx
+++ b/sw/source/uibase/shells/drwtxtex.cxx
@@ -178,16 +178,16 @@ void SwDrawTextShell::Execute( SfxRequest &rReq )
}
else
{
- FontUnderline eFU = static_cast<const SvxUnderlineItem&>(aEditAttr.Get(EE_CHAR_UNDERLINE)).GetLineStyle();
- aNewAttr.Put( SvxUnderlineItem(eFU == UNDERLINE_SINGLE ? UNDERLINE_NONE : UNDERLINE_SINGLE, EE_CHAR_UNDERLINE) );
+ FontLineStyle eFU = static_cast<const SvxUnderlineItem&>(aEditAttr.Get(EE_CHAR_UNDERLINE)).GetLineStyle();
+ aNewAttr.Put( SvxUnderlineItem(eFU == LINESTYLE_SINGLE ? LINESTYLE_NONE : LINESTYLE_SINGLE, EE_CHAR_UNDERLINE) );
}
}
break;
case SID_ATTR_CHAR_OVERLINE:
{
- FontUnderline eFO = static_cast<const SvxOverlineItem&>(aEditAttr.Get(EE_CHAR_OVERLINE)).GetLineStyle();
- aNewAttr.Put(SvxOverlineItem(eFO == UNDERLINE_SINGLE ? UNDERLINE_NONE : UNDERLINE_SINGLE, EE_CHAR_OVERLINE));
+ FontLineStyle eFO = static_cast<const SvxOverlineItem&>(aEditAttr.Get(EE_CHAR_OVERLINE)).GetLineStyle();
+ aNewAttr.Put(SvxOverlineItem(eFO == LINESTYLE_SINGLE ? LINESTYLE_NONE : LINESTYLE_SINGLE, EE_CHAR_OVERLINE));
}
break;
diff --git a/sw/source/uibase/shells/txtattr.cxx b/sw/source/uibase/shells/txtattr.cxx
index 3d004231fa01..43d4eef57fd5 100644
--- a/sw/source/uibase/shells/txtattr.cxx
+++ b/sw/source/uibase/shells/txtattr.cxx
@@ -135,20 +135,20 @@ void SwTextShell::ExecCharAttr(SfxRequest &rReq)
break;
case FN_UNDERLINE_DOUBLE:
{
- FontUnderline eUnderline = static_cast<const SvxUnderlineItem&>(
+ FontLineStyle eUnderline = static_cast<const SvxUnderlineItem&>(
aSet.Get(RES_CHRATR_UNDERLINE)).GetLineStyle();
switch( eState )
{
case STATE_TOGGLE:
- eUnderline = eUnderline == UNDERLINE_DOUBLE ?
- UNDERLINE_NONE :
- UNDERLINE_DOUBLE;
+ eUnderline = eUnderline == LINESTYLE_DOUBLE ?
+ LINESTYLE_NONE :
+ LINESTYLE_DOUBLE;
break;
case STATE_ON:
- eUnderline = UNDERLINE_DOUBLE;
+ eUnderline = LINESTYLE_DOUBLE;
break;
case STATE_OFF:
- eUnderline = UNDERLINE_NONE;
+ eUnderline = LINESTYLE_NONE;
break;
}
SvxUnderlineItem aUnderline(eUnderline, RES_CHRATR_UNDERLINE );
@@ -659,9 +659,9 @@ void SwTextShell::GetAttrState(SfxItemSet &rSet)
eState = aCoreSet.GetItemState(RES_CHRATR_UNDERLINE);
if( eState >= SfxItemState::DEFAULT )
{
- FontUnderline eUnderline = static_cast<const SvxUnderlineItem&>(
+ FontLineStyle eUnderline = static_cast<const SvxUnderlineItem&>(
aCoreSet.Get(RES_CHRATR_UNDERLINE)).GetLineStyle();
- rSet.Put(SfxBoolItem(nSlot, eUnderline == UNDERLINE_DOUBLE));
+ rSet.Put(SfxBoolItem(nSlot, eUnderline == LINESTYLE_DOUBLE));
}
else
rSet.InvalidateItem(nSlot);
diff --git a/sw/source/core/txtnode/fntcache.cxx b/sw/source/core/txtnode/fntcache.cxx
index 3f54a1735fe7..e0910e20be20 100644
--- a/sw/source/core/txtnode/fntcache.cxx
+++ b/sw/source/core/txtnode/fntcache.cxx
@@ -120,8 +120,8 @@ SwFntObj::SwFntObj(const SwSubFont &rFont, const void *pOwn, SwViewShell const *
{
nZoom = pSh ? pSh->GetViewOptions()->GetZoom() : USHRT_MAX;
bSymbol = RTL_TEXTENCODING_SYMBOL == aFont.GetCharSet();
- bPaintBlank = ( UNDERLINE_NONE != aFont.GetUnderline()
- || UNDERLINE_NONE != aFont.GetOverline()
+ bPaintBlank = ( LINESTYLE_NONE != aFont.GetUnderline()
+ || LINESTYLE_NONE != aFont.GetOverline()
|| STRIKEOUT_NONE != aFont.GetStrikeout() )
&& !aFont.IsWordLineMode();
aFont.SetLanguage(rFont.GetLanguage());
@@ -869,7 +869,7 @@ void SwFntObj::DrawText( SwDrawTextInfo &rInf )
if ( ! pTmpFont )
pTmpFont = pPrtFont;
// HACK: UNDERLINE_WAVE must not be abused any more, hence the grey wave
// line of the ExtendedAttributeSets will appear in the font color first
const bool bSwitchH2V = rInf.GetFrame() && rInf.GetFrame()->IsVertical();
@@ -1772,13 +1772,13 @@ void SwFntObj::DrawText( SwDrawTextInfo &rInf )
rInf.GetOut().Push();
Color aPreviousColor = pTmpFont->GetColor();
- FontUnderline aPreviousUnderline = pTmpFont->GetUnderline();
- FontUnderline aPreviousOverline = pTmpFont->GetOverline();
+ FontLineStyle aPreviousUnderline = pTmpFont->GetUnderline();
+ FontLineStyle aPreviousOverline = pTmpFont->GetOverline();
FontStrikeout aPreviousStrikeout = pTmpFont->GetStrikeout();
pTmpFont->SetColor( Color(NON_PRINTING_CHARACTER_COLOR) );
- pTmpFont->SetUnderline(UNDERLINE_NONE);
- pTmpFont->SetOverline(UNDERLINE_NONE);
+ pTmpFont->SetUnderline(LINESTYLE_NONE);
+ pTmpFont->SetOverline(LINESTYLE_NONE);
pTmpFont->SetStrikeout(STRIKEOUT_NONE);
rInf.GetOut().SetFont( *pTmpFont );
long nShift = rInf.GetOut( ).GetFontMetric( ).GetBulletOffset( );
@@ -869,7 +869,7 @@ void SwFntObj::DrawText( SwDrawTextInfo &rInf )
if ( ! pTmpFont )
pTmpFont = pPrtFont;
- // HACK: UNDERLINE_WAVE must not be abused any more, hence the grey wave
+ // HACK: LINESTYLE_WAVE must not be abused any more, hence the grey wave
// line of the ExtendedAttributeSets will appear in the font color first
const bool bSwitchH2V = rInf.GetFrame() && rInf.GetFrame()->IsVertical();